@@ -39,7 +39,9 @@ def format_datetime_column_with_unit(
     df: pd.DataFrame, datetime_column: str, time_unit: TimeUnit
 ) -> pd.DataFrame:
     """Turns date column into `str` based on given `time_unit`. Will modify the original `df`."""
-    df[datetime_column] = df[datetime_column].apply(lambda t: time_unit.format(t))
+    df[datetime_column] = df[datetime_column].apply(
+        lambda t: time_unit.format_datetime(t)
+    )
     return df
 
 
