@@ -3,7 +3,6 @@ import math
 from typing import Callable, DefaultDict, Dict, List, Union
 
 import numpy as np
-import numpy.typing as npt
 from pydantic import BaseModel, validator
 from pydantic.types import NonNegativeFloat
 from sklearn import preprocessing
@@ -45,7 +44,7 @@ class RegressionScores(BaseModel):
         return v
 
     @classmethod
-    def get_scores(cls, pred: npt.NDArray[np.float64], actual: npt.NDArray[np.float64]):
+    def get_scores(cls, pred: np.ndarray, actual: np.ndarray):
         """
         Calculate the regrssion scores according to a set of predicted values (`pred`) and actual values (`actual`).
 
