@@ -41,6 +41,35 @@ class MinioURI(BaseModel):
             raise ExodusForbidden(f"Invalid scheme: {parsed.scheme}")
         return cls(bucket=parsed.netloc, key=parsed.path.lstrip("/"))
 
+    def put_df(self, minio: Minio, df: pd.DataFrame) -> str:
+        """
+        Stores the given Pandas DataFrame in Minio as a CSV object, and returns its URI as `str`.
+
+        Parameters
+        ----------
+        minio : Minio
+            The minio client
+        df : pd.DataFrame
+            The dataframe to store
+
+        Returns
+        -------
+        str
+            The URI for the stored dataframe, as a `str`.
+        """
+        csv_bytes = df.to_csv(index=False).encode("utf-8")
+        csv_buffer = BytesIO(csv_bytes)
+        if not minio.bucket_exists(self.bucket):
+            minio.make_bucket(self.bucket)
+        minio.put_object(
+            self.bucket,
+            self.key,
+            csv_buffer,
+            length=len(csv_bytes),
+            content_type="application/csv",
+        )
+        return self.url
+
     def get_df(self, minio: Minio, header: List[str]) -> Optional[pd.DataFrame]:
         """
         Returns a Pandas dataframe parsed from this Minio URI. Returns `None` on failure.
